coalib.bearlib.aspects package — coala 0.9.0.dev99999999999999 documentation

# coalib.bearlib.aspects package

## Submodules

## coalib.bearlib.aspects.Metadata module

class `coalib.bearlib.aspects.Metadata.` `Body`(language, **taste_values)

  Bases: `coalib.bearlib.aspects.Metadata.Body`, `coalib.bearlib.aspects.base.aspectbase`

  class `Existence`(language, **taste_values)

    Bases: `coalib.bearlib.aspects.Metadata.Existence`, `coalib.bearlib.aspects.base.aspectbase`

    `docs` = <coalib.bearlib.aspects.docs.Documentation object>
    `parent`

      alias of `Body`

    `subaspects` = {}
  class `Body.` `Length`(language, **taste_values)

    Bases: `coalib.bearlib.aspects.Metadata.Length`, `coalib.bearlib.aspects.base.aspectbase`

    `docs` = <coalib.bearlib.aspects.docs.Documentation object>
    `parent`

      alias of `Body`

    `subaspects` = {}
  `Body.` `docs` = <coalib.bearlib.aspects.docs.Documentation object>
  `Body.` `parent`

    alias of `CommitMessage`

  `Body.` `subaspects` = {'Length': <aspectclass 'Root.Metadata.CommitMessage.Body.Length'>, 'Existence': <aspectclass 'Root.Metadata.CommitMessage.Body.Existence'>}

class `coalib.bearlib.aspects.Metadata.` `ColonExistence`(language, **taste_values)

  Bases: `coalib.bearlib.aspects.Metadata.ColonExistence`, `coalib.bearlib.aspects.base.aspectbase`

  `docs` = <coalib.bearlib.aspects.docs.Documentation object>
  `parent`

    alias of `Shortlog`

  `subaspects` = {}

class `coalib.bearlib.aspects.Metadata.` `CommitMessage`(language, **taste_values)

  Bases: `coalib.bearlib.aspects.Metadata.CommitMessage`, `coalib.bearlib.aspects.base.aspectbase`

  class `Body`(language, **taste_values)

    Bases: `coalib.bearlib.aspects.Metadata.Body`, `coalib.bearlib.aspects.base.aspectbase`

    class `Existence`(language, **taste_values)

      Bases: `coalib.bearlib.aspects.Metadata.Existence`, `coalib.bearlib.aspects.base.aspectbase`

      `docs` = <coalib.bearlib.aspects.docs.Documentation object>
      `parent`

        alias of `Body`

      `subaspects` = {}
    class `CommitMessage.Body.` `Length`(language, **taste_values)

      Bases: `coalib.bearlib.aspects.Metadata.Length`, `coalib.bearlib.aspects.base.aspectbase`

      `docs` = <coalib.bearlib.aspects.docs.Documentation object>
      `parent`

        alias of `Body`

      `subaspects` = {}
    `CommitMessage.Body.` `docs` = <coalib.bearlib.aspects.docs.Documentation object>
    `CommitMessage.Body.` `parent`

      alias of `CommitMessage`

    `CommitMessage.Body.` `subaspects` = {'Length': <aspectclass 'Root.Metadata.CommitMessage.Body.Length'>, 'Existence': <aspectclass 'Root.Metadata.CommitMessage.Body.Existence'>}
  class `CommitMessage.` `Emptiness`(language, **taste_values)

    Bases: `coalib.bearlib.aspects.Metadata.Emptiness`, `coalib.bearlib.aspects.base.aspectbase`

    `docs` = <coalib.bearlib.aspects.docs.Documentation object>
    `parent`

      alias of `CommitMessage`

    `subaspects` = {}
  class `CommitMessage.` `Shortlog`(language, **taste_values)

    Bases: `coalib.bearlib.aspects.Metadata.Shortlog`, `coalib.bearlib.aspects.base.aspectbase`

    class `ColonExistence`(language, **taste_values)

      Bases: `coalib.bearlib.aspects.Metadata.ColonExistence`, `coalib.bearlib.aspects.base.aspectbase`

      `docs` = <coalib.bearlib.aspects.docs.Documentation object>
      `parent`

        alias of `Shortlog`

      `subaspects` = {}
    class `CommitMessage.Shortlog.` `FirstCharacter`(language, **taste_values)

      Bases: `coalib.bearlib.aspects.Metadata.FirstCharacter`, `coalib.bearlib.aspects.base.aspectbase`

      `docs` = <coalib.bearlib.aspects.docs.Documentation object>
      `parent`

        alias of `Shortlog`

      `subaspects` = {}
    class `CommitMessage.Shortlog.` `Length`(language, **taste_values)

      Bases: `coalib.bearlib.aspects.Metadata.Length`, `coalib.bearlib.aspects.base.aspectbase`

      `docs` = <coalib.bearlib.aspects.docs.Documentation object>
      `parent`

        alias of `Shortlog`

      `subaspects` = {}
    class `CommitMessage.Shortlog.` `Tense`(language, **taste_values)

      Bases: `coalib.bearlib.aspects.Metadata.Tense`, `coalib.bearlib.aspects.base.aspectbase`

      `docs` = <coalib.bearlib.aspects.docs.Documentation object>
      `parent`

        alias of `Shortlog`

      `subaspects` = {}
    class `CommitMessage.Shortlog.` `TrailingPeriod`(language, **taste_values)

      Bases: `coalib.bearlib.aspects.Metadata.TrailingPeriod`, `coalib.bearlib.aspects.base.aspectbase`

      `docs` = <coalib.bearlib.aspects.docs.Documentation object>
      `parent`

        alias of `Shortlog`

      `subaspects` = {}
    `CommitMessage.Shortlog.` `docs` = <coalib.bearlib.aspects.docs.Documentation object>
    `CommitMessage.Shortlog.` `parent`

      alias of `CommitMessage`

    `CommitMessage.Shortlog.` `subaspects` = {'Tense': <aspectclass 'Root.Metadata.CommitMessage.Shortlog.Tense'>, 'FirstCharacter': <aspectclass 'Root.Metadata.CommitMessage.Shortlog.FirstCharacter'>, 'ColonExistence': <aspectclass 'Root.Metadata.CommitMessage.Shortlog.ColonExistence'>, 'Length': <aspectclass 'Root.Metadata.CommitMessage.Shortlog.Length'>, 'TrailingPeriod': <aspectclass 'Root.Metadata.CommitMessage.Shortlog.TrailingPeriod'>}
  `CommitMessage.` `docs` = <coalib.bearlib.aspects.docs.Documentation object>
  `CommitMessage.` `parent`

    alias of `Metadata`

  `CommitMessage.` `subaspects` = {'Emptiness': <aspectclass 'Root.Metadata.CommitMessage.Emptiness'>, 'Shortlog': <aspectclass 'Root.Metadata.CommitMessage.Shortlog'>, 'Body': <aspectclass 'Root.Metadata.CommitMessage.Body'>}

class `coalib.bearlib.aspects.Metadata.` `Emptiness`(language, **taste_values)

  Bases: `coalib.bearlib.aspects.Metadata.Emptiness`, `coalib.bearlib.aspects.base.aspectbase`

  `docs` = <coalib.bearlib.aspects.docs.Documentation object>
  `parent`

    alias of `CommitMessage`

  `subaspects` = {}

class `coalib.bearlib.aspects.Metadata.` `Existence`(language, **taste_values)

  Bases: `coalib.bearlib.aspects.Metadata.Existence`, `coalib.bearlib.aspects.base.aspectbase`

  `docs` = <coalib.bearlib.aspects.docs.Documentation object>
  `parent`

    alias of `Body`

  `subaspects` = {}

class `coalib.bearlib.aspects.Metadata.` `FirstCharacter`(language, **taste_values)

  Bases: `coalib.bearlib.aspects.Metadata.FirstCharacter`, `coalib.bearlib.aspects.base.aspectbase`

  `docs` = <coalib.bearlib.aspects.docs.Documentation object>
  `parent`

    alias of `Shortlog`

  `subaspects` = {}

class `coalib.bearlib.aspects.Metadata.` `Length`(language, **taste_values)

  Bases: `coalib.bearlib.aspects.Metadata.Length`, `coalib.bearlib.aspects.base.aspectbase`

  `docs` = <coalib.bearlib.aspects.docs.Documentation object>
  `parent`

    alias of `Body`

  `subaspects` = {}

class `coalib.bearlib.aspects.Metadata.` `Metadata`(language, **taste_values)

  Bases: `coalib.bearlib.aspects.Metadata.Metadata`, `coalib.bearlib.aspects.base.aspectbase`

  class `CommitMessage`(language, **taste_values)

    Bases: `coalib.bearlib.aspects.Metadata.CommitMessage`, `coalib.bearlib.aspects.base.aspectbase`

    class `Body`(language, **taste_values)

      Bases: `coalib.bearlib.aspects.Metadata.Body`, `coalib.bearlib.aspects.base.aspectbase`

      class `Existence`(language, **taste_values)

        Bases: `coalib.bearlib.aspects.Metadata.Existence`, `coalib.bearlib.aspects.base.aspectbase`

        `docs` = <coalib.bearlib.aspects.docs.Documentation object>
        `parent`

          alias of `Body`

        `subaspects` = {}
      class `Metadata.CommitMessage.Body.` `Length`(language, **taste_values)

        Bases: `coalib.bearlib.aspects.Metadata.Length`, `coalib.bearlib.aspects.base.aspectbase`

        `docs` = <coalib.bearlib.aspects.docs.Documentation object>
        `parent`

          alias of `Body`

        `subaspects` = {}
      `Metadata.CommitMessage.Body.` `docs` = <coalib.bearlib.aspects.docs.Documentation object>
      `Metadata.CommitMessage.Body.` `parent`

        alias of `CommitMessage`

      `Metadata.CommitMessage.Body.` `subaspects` = {'Length': <aspectclass 'Root.Metadata.CommitMessage.Body.Length'>, 'Existence': <aspectclass 'Root.Metadata.CommitMessage.Body.Existence'>}
    class `Metadata.CommitMessage.` `Emptiness`(language, **taste_values)

      Bases: `coalib.bearlib.aspects.Metadata.Emptiness`, `coalib.bearlib.aspects.base.aspectbase`

      `docs` = <coalib.bearlib.aspects.docs.Documentation object>
      `parent`

        alias of `CommitMessage`

      `subaspects` = {}
    class `Metadata.CommitMessage.` `Shortlog`(language, **taste_values)

      Bases: `coalib.bearlib.aspects.Metadata.Shortlog`, `coalib.bearlib.aspects.base.aspectbase`

      class `ColonExistence`(language, **taste_values)

        Bases: `coalib.bearlib.aspects.Metadata.ColonExistence`, `coalib.bearlib.aspects.base.aspectbase`

        `docs` = <coalib.bearlib.aspects.docs.Documentation object>
        `parent`

          alias of `Shortlog`

        `subaspects` = {}
      class `Metadata.CommitMessage.Shortlog.` `FirstCharacter`(language, **taste_values)

        Bases: `coalib.bearlib.aspects.Metadata.FirstCharacter`, `coalib.bearlib.aspects.base.aspectbase`

        `docs` = <coalib.bearlib.aspects.docs.Documentation object>
        `parent`

          alias of `Shortlog`

        `subaspects` = {}
      class `Metadata.CommitMessage.Shortlog.` `Length`(language, **taste_values)

        Bases: `coalib.bearlib.aspects.Metadata.Length`, `coalib.bearlib.aspects.base.aspectbase`

        `docs` = <coalib.bearlib.aspects.docs.Documentation object>
        `parent`

          alias of `Shortlog`

        `subaspects` = {}
      class `Metadata.CommitMessage.Shortlog.` `Tense`(language, **taste_values)

        Bases: `coalib.bearlib.aspects.Metadata.Tense`, `coalib.bearlib.aspects.base.aspectbase`

        `docs` = <coalib.bearlib.aspects.docs.Documentation object>
        `parent`

          alias of `Shortlog`

        `subaspects` = {}
      class `Metadata.CommitMessage.Shortlog.` `TrailingPeriod`(language, **taste_values)

        Bases: `coalib.bearlib.aspects.Metadata.TrailingPeriod`, `coalib.bearlib.aspects.base.aspectbase`

        `docs` = <coalib.bearlib.aspects.docs.Documentation object>
        `parent`

          alias of `Shortlog`

        `subaspects` = {}
      `Metadata.CommitMessage.Shortlog.` `docs` = <coalib.bearlib.aspects.docs.Documentation object>
      `Metadata.CommitMessage.Shortlog.` `parent`

        alias of `CommitMessage`

      `Metadata.CommitMessage.Shortlog.` `subaspects` = {'Tense': <aspectclass 'Root.Metadata.CommitMessage.Shortlog.Tense'>, 'FirstCharacter': <aspectclass 'Root.Metadata.CommitMessage.Shortlog.FirstCharacter'>, 'ColonExistence': <aspectclass 'Root.Metadata.CommitMessage.Shortlog.ColonExistence'>, 'Length': <aspectclass 'Root.Metadata.CommitMessage.Shortlog.Length'>, 'TrailingPeriod': <aspectclass 'Root.Metadata.CommitMessage.Shortlog.TrailingPeriod'>}
    `Metadata.CommitMessage.` `docs` = <coalib.bearlib.aspects.docs.Documentation object>
    `Metadata.CommitMessage.` `parent`

      alias of `Metadata`

    `Metadata.CommitMessage.` `subaspects` = {'Emptiness': <aspectclass 'Root.Metadata.CommitMessage.Emptiness'>, 'Shortlog': <aspectclass 'Root.Metadata.CommitMessage.Shortlog'>, 'Body': <aspectclass 'Root.Metadata.CommitMessage.Body'>}
  `Metadata.` `docs` = <coalib.bearlib.aspects.docs.Documentation object>
  `Metadata.` `parent`

    alias of `Root`

  `Metadata.` `subaspects` = {'CommitMessage': <aspectclass 'Root.Metadata.CommitMessage'>}

class `coalib.bearlib.aspects.Metadata.` `Shortlog`(language, **taste_values)

  Bases: `coalib.bearlib.aspects.Metadata.Shortlog`, `coalib.bearlib.aspects.base.aspectbase`

  class `ColonExistence`(language, **taste_values)

    Bases: `coalib.bearlib.aspects.Metadata.ColonExistence`, `coalib.bearlib.aspects.base.aspectbase`

    `docs` = <coalib.bearlib.aspects.docs.Documentation object>
    `parent`

      alias of `Shortlog`

    `subaspects` = {}
  class `Shortlog.` `FirstCharacter`(language, **taste_values)

    Bases: `coalib.bearlib.aspects.Metadata.FirstCharacter`, `coalib.bearlib.aspects.base.aspectbase`

    `docs` = <coalib.bearlib.aspects.docs.Documentation object>
    `parent`

      alias of `Shortlog`

    `subaspects` = {}
  class `Shortlog.` `Length`(language, **taste_values)

    Bases: `coalib.bearlib.aspects.Metadata.Length`, `coalib.bearlib.aspects.base.aspectbase`

    `docs` = <coalib.bearlib.aspects.docs.Documentation object>
    `parent`

      alias of `Shortlog`

    `subaspects` = {}
  class `Shortlog.` `Tense`(language, **taste_values)

    Bases: `coalib.bearlib.aspects.Metadata.Tense`, `coalib.bearlib.aspects.base.aspectbase`

    `docs` = <coalib.bearlib.aspects.docs.Documentation object>
    `parent`

      alias of `Shortlog`

    `subaspects` = {}
  class `Shortlog.` `TrailingPeriod`(language, **taste_values)

    Bases: `coalib.bearlib.aspects.Metadata.TrailingPeriod`, `coalib.bearlib.aspects.base.aspectbase`

    `docs` = <coalib.bearlib.aspects.docs.Documentation object>
    `parent`

      alias of `Shortlog`

    `subaspects` = {}
  `Shortlog.` `docs` = <coalib.bearlib.aspects.docs.Documentation object>
  `Shortlog.` `parent`

    alias of `CommitMessage`

  `Shortlog.` `subaspects` = {'Tense': <aspectclass 'Root.Metadata.CommitMessage.Shortlog.Tense'>, 'FirstCharacter': <aspectclass 'Root.Metadata.CommitMessage.Shortlog.FirstCharacter'>, 'ColonExistence': <aspectclass 'Root.Metadata.CommitMessage.Shortlog.ColonExistence'>, 'Length': <aspectclass 'Root.Metadata.CommitMessage.Shortlog.Length'>, 'TrailingPeriod': <aspectclass 'Root.Metadata.CommitMessage.Shortlog.TrailingPeriod'>}

class `coalib.bearlib.aspects.Metadata.` `Tense`(language, **taste_values)

  Bases: `coalib.bearlib.aspects.Metadata.Tense`, `coalib.bearlib.aspects.base.aspectbase`

  `docs` = <coalib.bearlib.aspects.docs.Documentation object>
  `parent`

    alias of `Shortlog`

  `subaspects` = {}

class `coalib.bearlib.aspects.Metadata.` `TrailingPeriod`(language, **taste_values)

  Bases: `coalib.bearlib.aspects.Metadata.TrailingPeriod`, `coalib.bearlib.aspects.base.aspectbase`

  `docs` = <coalib.bearlib.aspects.docs.Documentation object>
  `parent`

    alias of `Shortlog`

  `subaspects` = {}

## coalib.bearlib.aspects.Redundancy module

class `coalib.bearlib.aspects.Redundancy.` `Clone`(language, **taste_values)

  Bases: `coalib.bearlib.aspects.Redundancy.Clone`, `coalib.bearlib.aspects.base.aspectbase`

  `docs` = <coalib.bearlib.aspects.docs.Documentation object>
  `parent`

    alias of `Redundancy`

  `subaspects` = {}

class `coalib.bearlib.aspects.Redundancy.` `Redundancy`(language, **taste_values)

  Bases: `coalib.bearlib.aspects.Redundancy.Redundancy`, `coalib.bearlib.aspects.base.aspectbase`

  class `Clone`(language, **taste_values)

    Bases: `coalib.bearlib.aspects.Redundancy.Clone`, `coalib.bearlib.aspects.base.aspectbase`

    `docs` = <coalib.bearlib.aspects.docs.Documentation object>
    `parent`

      alias of `Redundancy`

    `subaspects` = {}
  class `Redundancy.` `UnreachableCode`(language, **taste_values)

    Bases: `coalib.bearlib.aspects.Redundancy.UnreachableCode`, `coalib.bearlib.aspects.base.aspectbase`

    class `UnreachableStatement`(language, **taste_values)

      Bases: `coalib.bearlib.aspects.Redundancy.UnreachableStatement`, `coalib.bearlib.aspects.base.aspectbase`

      `docs` = <coalib.bearlib.aspects.docs.Documentation object>
      `parent`

        alias of `UnreachableCode`

      `subaspects` = {}
    class `Redundancy.UnreachableCode.` `UnusedFunction`(language, **taste_values)

      Bases: `coalib.bearlib.aspects.Redundancy.UnusedFunction`, `coalib.bearlib.aspects.base.aspectbase`

      `docs` = <coalib.bearlib.aspects.docs.Documentation object>
      `parent`

        alias of `UnreachableCode`

      `subaspects` = {}
    `Redundancy.UnreachableCode.` `docs` = <coalib.bearlib.aspects.docs.Documentation object>
    `Redundancy.UnreachableCode.` `parent`

      alias of `Redundancy`

    `Redundancy.UnreachableCode.` `subaspects` = {'UnreachableStatement': <aspectclass 'Root.Redundancy.UnreachableCode.UnreachableStatement'>, 'UnusedFunction': <aspectclass 'Root.Redundancy.UnreachableCode.UnusedFunction'>}
  class `Redundancy.` `UnusedImport`(language, **taste_values)

    Bases: `coalib.bearlib.aspects.Redundancy.UnusedImport`, `coalib.bearlib.aspects.base.aspectbase`

    `docs` = <coalib.bearlib.aspects.docs.Documentation object>
    `parent`

      alias of `Redundancy`

    `subaspects` = {}
  class `Redundancy.` `UnusedVariable`(language, **taste_values)

    Bases: `coalib.bearlib.aspects.Redundancy.UnusedVariable`, `coalib.bearlib.aspects.base.aspectbase`

    class `UnusedGlobalVariable`(language, **taste_values)

      Bases: `coalib.bearlib.aspects.Redundancy.UnusedGlobalVariable`, `coalib.bearlib.aspects.base.aspectbase`

      `docs` = <coalib.bearlib.aspects.docs.Documentation object>
      `parent`

        alias of `UnusedVariable`

      `subaspects` = {}
    class `Redundancy.UnusedVariable.` `UnusedLocalVariable`(language, **taste_values)

      Bases: `coalib.bearlib.aspects.Redundancy.UnusedLocalVariable`, `coalib.bearlib.aspects.base.aspectbase`

      `docs` = <coalib.bearlib.aspects.docs.Documentation object>
      `parent`

        alias of `UnusedVariable`

      `subaspects` = {}
    class `Redundancy.UnusedVariable.` `UnusedParameter`(language, **taste_values)

      Bases: `coalib.bearlib.aspects.Redundancy.UnusedParameter`, `coalib.bearlib.aspects.base.aspectbase`

      `docs` = <coalib.bearlib.aspects.docs.Documentation object>
      `parent`

        alias of `UnusedVariable`

      `subaspects` = {}
    `Redundancy.UnusedVariable.` `docs` = <coalib.bearlib.aspects.docs.Documentation object>
    `Redundancy.UnusedVariable.` `parent`

      alias of `Redundancy`

    `Redundancy.UnusedVariable.` `subaspects` = {'UnusedLocalVariable': <aspectclass 'Root.Redundancy.UnusedVariable.UnusedLocalVariable'>, 'UnusedGlobalVariable': <aspectclass 'Root.Redundancy.UnusedVariable.UnusedGlobalVariable'>, 'UnusedParameter': <aspectclass 'Root.Redundancy.UnusedVariable.UnusedParameter'>}
  `Redundancy.` `docs` = <coalib.bearlib.aspects.docs.Documentation object>
  `Redundancy.` `parent`

    alias of `Root`

  `Redundancy.` `subaspects` = {'UnreachableCode': <aspectclass 'Root.Redundancy.UnreachableCode'>, 'UnusedVariable': <aspectclass 'Root.Redundancy.UnusedVariable'>, 'Clone': <aspectclass 'Root.Redundancy.Clone'>, 'UnusedImport': <aspectclass 'Root.Redundancy.UnusedImport'>}

class `coalib.bearlib.aspects.Redundancy.` `UnreachableCode`(language, **taste_values)

  Bases: `coalib.bearlib.aspects.Redundancy.UnreachableCode`, `coalib.bearlib.aspects.base.aspectbase`

  class `UnreachableStatement`(language, **taste_values)

    Bases: `coalib.bearlib.aspects.Redundancy.UnreachableStatement`, `coalib.bearlib.aspects.base.aspectbase`

    `docs` = <coalib.bearlib.aspects.docs.Documentation object>
    `parent`

      alias of `UnreachableCode`

    `subaspects` = {}
  class `UnreachableCode.` `UnusedFunction`(language, **taste_values)

    Bases: `coalib.bearlib.aspects.Redundancy.UnusedFunction`, `coalib.bearlib.aspects.base.aspectbase`

    `docs` = <coalib.bearlib.aspects.docs.Documentation object>
    `parent`

      alias of `UnreachableCode`

    `subaspects` = {}
  `UnreachableCode.` `docs` = <coalib.bearlib.aspects.docs.Documentation object>
  `UnreachableCode.` `parent`

    alias of `Redundancy`

  `UnreachableCode.` `subaspects` = {'UnreachableStatement': <aspectclass 'Root.Redundancy.UnreachableCode.UnreachableStatement'>, 'UnusedFunction': <aspectclass 'Root.Redundancy.UnreachableCode.UnusedFunction'>}

class `coalib.bearlib.aspects.Redundancy.` `UnreachableStatement`(language, **taste_values)

  Bases: `coalib.bearlib.aspects.Redundancy.UnreachableStatement`, `coalib.bearlib.aspects.base.aspectbase`

  `docs` = <coalib.bearlib.aspects.docs.Documentation object>
  `parent`

    alias of `UnreachableCode`

  `subaspects` = {}

class `coalib.bearlib.aspects.Redundancy.` `UnusedFunction`(language, **taste_values)

  Bases: `coalib.bearlib.aspects.Redundancy.UnusedFunction`, `coalib.bearlib.aspects.base.aspectbase`

  `docs` = <coalib.bearlib.aspects.docs.Documentation object>
  `parent`

    alias of `UnreachableCode`

  `subaspects` = {}

class `coalib.bearlib.aspects.Redundancy.` `UnusedGlobalVariable`(language, **taste_values)

  Bases: `coalib.bearlib.aspects.Redundancy.UnusedGlobalVariable`, `coalib.bearlib.aspects.base.aspectbase`

  `docs` = <coalib.bearlib.aspects.docs.Documentation object>
  `parent`

    alias of `UnusedVariable`

  `subaspects` = {}

class `coalib.bearlib.aspects.Redundancy.` `UnusedImport`(language, **taste_values)

  Bases: `coalib.bearlib.aspects.Redundancy.UnusedImport`, `coalib.bearlib.aspects.base.aspectbase`

  `docs` = <coalib.bearlib.aspects.docs.Documentation object>
  `parent`

    alias of `Redundancy`

  `subaspects` = {}

class `coalib.bearlib.aspects.Redundancy.` `UnusedLocalVariable`(language, **taste_values)

  Bases: `coalib.bearlib.aspects.Redundancy.UnusedLocalVariable`, `coalib.bearlib.aspects.base.aspectbase`

  `docs` = <coalib.bearlib.aspects.docs.Documentation object>
  `parent`

    alias of `UnusedVariable`

  `subaspects` = {}

class `coalib.bearlib.aspects.Redundancy.` `UnusedParameter`(language, **taste_values)

  Bases: `coalib.bearlib.aspects.Redundancy.UnusedParameter`, `coalib.bearlib.aspects.base.aspectbase`

  `docs` = <coalib.bearlib.aspects.docs.Documentation object>
  `parent`

    alias of `UnusedVariable`

  `subaspects` = {}

class `coalib.bearlib.aspects.Redundancy.` `UnusedVariable`(language, **taste_values)

  Bases: `coalib.bearlib.aspects.Redundancy.UnusedVariable`, `coalib.bearlib.aspects.base.aspectbase`

  class `UnusedGlobalVariable`(language, **taste_values)

    Bases: `coalib.bearlib.aspects.Redundancy.UnusedGlobalVariable`, `coalib.bearlib.aspects.base.aspectbase`

    `docs` = <coalib.bearlib.aspects.docs.Documentation object>
    `parent`

      alias of `UnusedVariable`

    `subaspects` = {}
  class `UnusedVariable.` `UnusedLocalVariable`(language, **taste_values)

    Bases: `coalib.bearlib.aspects.Redundancy.UnusedLocalVariable`, `coalib.bearlib.aspects.base.aspectbase`

    `docs` = <coalib.bearlib.aspects.docs.Documentation object>
    `parent`

      alias of `UnusedVariable`

    `subaspects` = {}
  class `UnusedVariable.` `UnusedParameter`(language, **taste_values)

    Bases: `coalib.bearlib.aspects.Redundancy.UnusedParameter`, `coalib.bearlib.aspects.base.aspectbase`

    `docs` = <coalib.bearlib.aspects.docs.Documentation object>
    `parent`

      alias of `UnusedVariable`

    `subaspects` = {}
  `UnusedVariable.` `docs` = <coalib.bearlib.aspects.docs.Documentation object>
  `UnusedVariable.` `parent`

    alias of `Redundancy`

  `UnusedVariable.` `subaspects` = {'UnusedLocalVariable': <aspectclass 'Root.Redundancy.UnusedVariable.UnusedLocalVariable'>, 'UnusedGlobalVariable': <aspectclass 'Root.Redundancy.UnusedVariable.UnusedGlobalVariable'>, 'UnusedParameter': <aspectclass 'Root.Redundancy.UnusedVariable.UnusedParameter'>}

## coalib.bearlib.aspects.base module

class `coalib.bearlib.aspects.base.` `aspectbase`(language, **taste_values)

  Bases: `object`

  Base class for aspectclasses with common features for their instances.

  Derived classes must use `coalib.bearlib.aspectclasses.meta.aspectclass` as metaclass. This is automatically handled by `coalib.bearlib.aspectclasses.meta.aspectclass.subaspect()` decorator.

  `tastes`

    Get a dictionary of all taste names mapped to their specific values, including parent tastes.

## coalib.bearlib.aspects.docs module

class `coalib.bearlib.aspects.docs.` `Documentation`(definition: str = '', example: str = '', example_language: str = '', importance_reason: str = '', fix_suggestions: str = '')

  Bases: `object`

  This class contains documentation about an aspectclass. The documentation is consistent if all members are given:

      >>> Documentation('defined').check_consistency()
      False
      >>> Documentation('definition', 'example',
      ...               'example_language', 'importance',
      ...               'fix').check_consistency()
      True

  `check_consistency`()

## coalib.bearlib.aspects.meta module

class `coalib.bearlib.aspects.meta.` `aspectclass`(clsname, bases, clsattrs)

  Bases: `type`

  Metaclass for aspectclasses.

  Root aspectclass is `coalib.bearlib.aspectclasses.Root`.

  `subaspect`(subcls)

    The sub-aspectclass decorator.

    See `coalib.bearlib.aspectclasses.Root` for description and usage.

  `tastes`

    Get a dictionary of all taste names mapped to their `coalib.bearlib.aspectclasses.Taste` instances.

## coalib.bearlib.aspects.taste module

`coalib.bearlib.aspects.taste.` `Taste`

  Defines tastes in aspectclass definitions.

  Tastes can be made only available for certain languages by providing a `tuple` of language identifiers on instantiation:

      >>> Taste[bool](
      ...     'Ignore ``using`` directives in C#.',
      ...     (True, False), default=False,
      ...     languages=('CSharp', )
      ... ).languages
      (C#,)

  If no languages are given, they will be available for any language. See `coalib.bearlib.aspectclasses.Root` for further usage.

exception `coalib.bearlib.aspects.taste.` `TasteError`

  Bases: `AttributeError`

  A taste is not allowed to be accessed.

class `coalib.bearlib.aspects.taste.` `TasteMeta`

  Bases: `type`

  Metaclass for `coalib.bearlib.aspectclasses.Taste`

  Allows defining taste cast type via `__getitem__()`, like:

      >>> Taste[int]().cast_type
      <class 'int'>

## Module contents

class `coalib.bearlib.aspects.` `Root`(language, **taste_values)

  Bases: `coalib.bearlib.aspects.base.aspectbase`

  The root aspectclass.

  Define sub-aspectclasses with class-bound `.subaspect` decorator. Definition string is taken from doc-string of decorated class. Remaining docs are taken from a nested `docs` class. Tastes are defined as class attributes that are instances of `coalib.bearlib.aspectclasses.Taste`.

      >>> @Root.subaspect
      ... class Formatting:
      ...     """
      ...     A parent aspect for code formatting aspects...
      ...     """

  We can now create subaspects like this:

      >>> @Formatting.subaspect
      ... class LineLength:
      ...     """
      ...     This aspect controls the length of a line...
      ...     """
      ...     class docs:
      ...        example = "..."
      ...        example_language = "..."
      ...        importance_reason = "..."
      ...        fix_suggestions = "..."
      ...
      ...     max_line_length = Taste[int](
      ...         "Maximum length allowed for a line.",
      ...         (80, 90, 120), default=80)

  The representation will show the full “path” to the leaf of the tree:

      >>> Root.Formatting.LineLength
      <aspectclass 'Root.Formatting.LineLength'>

  We can see, which settings are availables:

      >>> Formatting.tastes
      {}
      >>> LineLength.tastes
      {'max_line_length': <....Taste[int] object at ...>}

  And instantiate the aspect with the values, they will be automatically converted:

      >>> Formatting('Python')
      <coalib.bearlib.aspects.Root.Formatting object at 0x...>
      >>> LineLength('Python', max_line_length="100").tastes
      {'max_line_length': 100}

  If no settings are given, the defaults will be taken> >>> LineLength(‘Python’).tastes {‘max_line_length’: 80}

  Tastes can also be made available for only specific languages:

      >>> from coalib.bearlib.languages import Language
      >>> @Language
      ... class GreaterTrumpScript:
      ...     pass

      >>> @Formatting.subaspect
      ... class Greatness:
      ...     """
      ...     This aspect controls the greatness of a file...
      ...     """
      ...
      ...     min_greatness = Taste[int](
      ...         "Minimum greatness factor needed for a TrumpScript file. "
      ...         "This is fact.",
      ...         (1000000, 1000000000, 1000000000000), default=1000000,
      ...         languages=('GreaterTrumpScript' ,))

      >>> Greatness.tastes
      {'min_greatness': <....Taste[int] object at ...>}
      >>> Greatness('GreaterTrumpScript').tastes
      {'min_greatness': 1000000}
      >>> Greatness('GreaterTrumpScript', min_greatness=1000000000000).tastes
      {'min_greatness': 1000000000000}

      >>> Greatness('Python').tastes
      {}

      >>> Greatness('Python', min_greatness=1000000000)
      ...
      Traceback (most recent call last):
        ...
      coalib.bearlib.aspects.taste.TasteError:
      Root.Formatting.Greatness.min_greatness is not available ...

      >>> Greatness('Python').min_greatness
      ...
      Traceback (most recent call last):
        ...
      coalib.bearlib.aspects.taste.TasteError:
      Root.Formatting.Greatness.min_greatness is not available ...

  class `Metadata`(language, **taste_values)

    Bases: `coalib.bearlib.aspects.Metadata.Metadata`, `coalib.bearlib.aspects.base.aspectbase`

    class `CommitMessage`(language, **taste_values)

      Bases: `coalib.bearlib.aspects.Metadata.CommitMessage`, `coalib.bearlib.aspects.base.aspectbase`

      class `Body`(language, **taste_values)

        Bases: `coalib.bearlib.aspects.Metadata.Body`, `coalib.bearlib.aspects.base.aspectbase`

        class `Existence`(language, **taste_values)

          Bases: `coalib.bearlib.aspects.Metadata.Existence`, `coalib.bearlib.aspects.base.aspectbase`

          `docs` = <coalib.bearlib.aspects.docs.Documentation object>
          `parent`

            alias of `Body`

          `subaspects` = {}
        class `Root.Metadata.CommitMessage.Body.` `Length`(language, **taste_values)

          Bases: `coalib.bearlib.aspects.Metadata.Length`, `coalib.bearlib.aspects.base.aspectbase`

          `docs` = <coalib.bearlib.aspects.docs.Documentation object>
          `parent`

            alias of `Body`

          `subaspects` = {}
        `Root.Metadata.CommitMessage.Body.` `docs` = <coalib.bearlib.aspects.docs.Documentation object>
        `Root.Metadata.CommitMessage.Body.` `parent`

          alias of `CommitMessage`

        `Root.Metadata.CommitMessage.Body.` `subaspects` = {'Length': <aspectclass 'Root.Metadata.CommitMessage.Body.Length'>, 'Existence': <aspectclass 'Root.Metadata.CommitMessage.Body.Existence'>}
      class `Root.Metadata.CommitMessage.` `Emptiness`(language, **taste_values)

        Bases: `coalib.bearlib.aspects.Metadata.Emptiness`, `coalib.bearlib.aspects.base.aspectbase`

        `docs` = <coalib.bearlib.aspects.docs.Documentation object>
        `parent`

          alias of `CommitMessage`

        `subaspects` = {}
      class `Root.Metadata.CommitMessage.` `Shortlog`(language, **taste_values)

        Bases: `coalib.bearlib.aspects.Metadata.Shortlog`, `coalib.bearlib.aspects.base.aspectbase`

        class `ColonExistence`(language, **taste_values)

          Bases: `coalib.bearlib.aspects.Metadata.ColonExistence`, `coalib.bearlib.aspects.base.aspectbase`

          `docs` = <coalib.bearlib.aspects.docs.Documentation object>
          `parent`

            alias of `Shortlog`

          `subaspects` = {}
        class `Root.Metadata.CommitMessage.Shortlog.` `FirstCharacter`(language, **taste_values)

          Bases: `coalib.bearlib.aspects.Metadata.FirstCharacter`, `coalib.bearlib.aspects.base.aspectbase`

          `docs` = <coalib.bearlib.aspects.docs.Documentation object>
          `parent`

            alias of `Shortlog`

          `subaspects` = {}
        class `Root.Metadata.CommitMessage.Shortlog.` `Length`(language, **taste_values)

          Bases: `coalib.bearlib.aspects.Metadata.Length`, `coalib.bearlib.aspects.base.aspectbase`

          `docs` = <coalib.bearlib.aspects.docs.Documentation object>
          `parent`

            alias of `Shortlog`

          `subaspects` = {}
        class `Root.Metadata.CommitMessage.Shortlog.` `Tense`(language, **taste_values)

          Bases: `coalib.bearlib.aspects.Metadata.Tense`, `coalib.bearlib.aspects.base.aspectbase`

          `docs` = <coalib.bearlib.aspects.docs.Documentation object>
          `parent`

            alias of `Shortlog`

          `subaspects` = {}
        class `Root.Metadata.CommitMessage.Shortlog.` `TrailingPeriod`(language, **taste_values)

          Bases: `coalib.bearlib.aspects.Metadata.TrailingPeriod`, `coalib.bearlib.aspects.base.aspectbase`

          `docs` = <coalib.bearlib.aspects.docs.Documentation object>
          `parent`

            alias of `Shortlog`

          `subaspects` = {}
        `Root.Metadata.CommitMessage.Shortlog.` `docs` = <coalib.bearlib.aspects.docs.Documentation object>
        `Root.Metadata.CommitMessage.Shortlog.` `parent`

          alias of `CommitMessage`

        `Root.Metadata.CommitMessage.Shortlog.` `subaspects` = {'Tense': <aspectclass 'Root.Metadata.CommitMessage.Shortlog.Tense'>, 'FirstCharacter': <aspectclass 'Root.Metadata.CommitMessage.Shortlog.FirstCharacter'>, 'ColonExistence': <aspectclass 'Root.Metadata.CommitMessage.Shortlog.ColonExistence'>, 'Length': <aspectclass 'Root.Metadata.CommitMessage.Shortlog.Length'>, 'TrailingPeriod': <aspectclass 'Root.Metadata.CommitMessage.Shortlog.TrailingPeriod'>}
      `Root.Metadata.CommitMessage.` `docs` = <coalib.bearlib.aspects.docs.Documentation object>
      `Root.Metadata.CommitMessage.` `parent`

        alias of `Metadata`

      `Root.Metadata.CommitMessage.` `subaspects` = {'Emptiness': <aspectclass 'Root.Metadata.CommitMessage.Emptiness'>, 'Shortlog': <aspectclass 'Root.Metadata.CommitMessage.Shortlog'>, 'Body': <aspectclass 'Root.Metadata.CommitMessage.Body'>}
    `Root.Metadata.` `docs` = <coalib.bearlib.aspects.docs.Documentation object>
    `Root.Metadata.` `parent`

      alias of `Root`

    `Root.Metadata.` `subaspects` = {'CommitMessage': <aspectclass 'Root.Metadata.CommitMessage'>}
  class `Root.` `Redundancy`(language, **taste_values)

    Bases: `coalib.bearlib.aspects.Redundancy.Redundancy`, `coalib.bearlib.aspects.base.aspectbase`

    class `Clone`(language, **taste_values)

      Bases: `coalib.bearlib.aspects.Redundancy.Clone`, `coalib.bearlib.aspects.base.aspectbase`

      `docs` = <coalib.bearlib.aspects.docs.Documentation object>
      `parent`

        alias of `Redundancy`

      `subaspects` = {}
    class `Root.Redundancy.` `UnreachableCode`(language, **taste_values)

      Bases: `coalib.bearlib.aspects.Redundancy.UnreachableCode`, `coalib.bearlib.aspects.base.aspectbase`

      class `UnreachableStatement`(language, **taste_values)

        Bases: `coalib.bearlib.aspects.Redundancy.UnreachableStatement`, `coalib.bearlib.aspects.base.aspectbase`

        `docs` = <coalib.bearlib.aspects.docs.Documentation object>
        `parent`

          alias of `UnreachableCode`

        `subaspects` = {}
      class `Root.Redundancy.UnreachableCode.` `UnusedFunction`(language, **taste_values)

        Bases: `coalib.bearlib.aspects.Redundancy.UnusedFunction`, `coalib.bearlib.aspects.base.aspectbase`

        `docs` = <coalib.bearlib.aspects.docs.Documentation object>
        `parent`

          alias of `UnreachableCode`

        `subaspects` = {}
      `Root.Redundancy.UnreachableCode.` `docs` = <coalib.bearlib.aspects.docs.Documentation object>
      `Root.Redundancy.UnreachableCode.` `parent`

        alias of `Redundancy`

      `Root.Redundancy.UnreachableCode.` `subaspects` = {'UnreachableStatement': <aspectclass 'Root.Redundancy.UnreachableCode.UnreachableStatement'>, 'UnusedFunction': <aspectclass 'Root.Redundancy.UnreachableCode.UnusedFunction'>}
    class `Root.Redundancy.` `UnusedImport`(language, **taste_values)

      Bases: `coalib.bearlib.aspects.Redundancy.UnusedImport`, `coalib.bearlib.aspects.base.aspectbase`

      `docs` = <coalib.bearlib.aspects.docs.Documentation object>
      `parent`

        alias of `Redundancy`

      `subaspects` = {}
    class `Root.Redundancy.` `UnusedVariable`(language, **taste_values)

      Bases: `coalib.bearlib.aspects.Redundancy.UnusedVariable`, `coalib.bearlib.aspects.base.aspectbase`

      class `UnusedGlobalVariable`(language, **taste_values)

        Bases: `coalib.bearlib.aspects.Redundancy.UnusedGlobalVariable`, `coalib.bearlib.aspects.base.aspectbase`

        `docs` = <coalib.bearlib.aspects.docs.Documentation object>
        `parent`

          alias of `UnusedVariable`

        `subaspects` = {}
      class `Root.Redundancy.UnusedVariable.` `UnusedLocalVariable`(language, **taste_values)

        Bases: `coalib.bearlib.aspects.Redundancy.UnusedLocalVariable`, `coalib.bearlib.aspects.base.aspectbase`

        `docs` = <coalib.bearlib.aspects.docs.Documentation object>
        `parent`

          alias of `UnusedVariable`

        `subaspects` = {}
      class `Root.Redundancy.UnusedVariable.` `UnusedParameter`(language, **taste_values)

        Bases: `coalib.bearlib.aspects.Redundancy.UnusedParameter`, `coalib.bearlib.aspects.base.aspectbase`

        `docs` = <coalib.bearlib.aspects.docs.Documentation object>
        `parent`

          alias of `UnusedVariable`

        `subaspects` = {}
      `Root.Redundancy.UnusedVariable.` `docs` = <coalib.bearlib.aspects.docs.Documentation object>
      `Root.Redundancy.UnusedVariable.` `parent`

        alias of `Redundancy`

      `Root.Redundancy.UnusedVariable.` `subaspects` = {'UnusedLocalVariable': <aspectclass 'Root.Redundancy.UnusedVariable.UnusedLocalVariable'>, 'UnusedGlobalVariable': <aspectclass 'Root.Redundancy.UnusedVariable.UnusedGlobalVariable'>, 'UnusedParameter': <aspectclass 'Root.Redundancy.UnusedVariable.UnusedParameter'>}
    `Root.Redundancy.` `docs` = <coalib.bearlib.aspects.docs.Documentation object>
    `Root.Redundancy.` `parent`

      alias of `Root`

    `Root.Redundancy.` `subaspects` = {'UnreachableCode': <aspectclass 'Root.Redundancy.UnreachableCode'>, 'UnusedVariable': <aspectclass 'Root.Redundancy.UnusedVariable'>, 'Clone': <aspectclass 'Root.Redundancy.Clone'>, 'UnusedImport': <aspectclass 'Root.Redundancy.UnusedImport'>}
  `Root.` `parent` = None
  `Root.` `subaspects` = {'Metadata': <aspectclass 'Root.Metadata'>, 'Redundancy': <aspectclass 'Root.Redundancy'>}

`coalib.bearlib.aspects.` `Taste`

  Defines tastes in aspectclass definitions.

  Tastes can be made only available for certain languages by providing a `tuple` of language identifiers on instantiation:

      >>> Taste[bool](
      ...     'Ignore ``using`` directives in C#.',
      ...     (True, False), default=False,
      ...     languages=('CSharp', )
      ... ).languages
      (C#,)

  If no languages are given, they will be available for any language. See `coalib.bearlib.aspectclasses.Root` for further usage.

exception `coalib.bearlib.aspects.` `TasteError`

  Bases: `AttributeError`

  A taste is not allowed to be accessed.

class `coalib.bearlib.aspects.` `aspectclass`(clsname, bases, clsattrs)

  Bases: `type`

  Metaclass for aspectclasses.

  Root aspectclass is `coalib.bearlib.aspectclasses.Root`.

  `subaspect`(subcls)

    The sub-aspectclass decorator.

    See `coalib.bearlib.aspectclasses.Root` for description and usage.

  `tastes`

    Get a dictionary of all taste names mapped to their `coalib.bearlib.aspectclasses.Taste` instances.